@@ -1,4 +1,4 @@
-# $Id: PoeBuildInfo.pm 2387 2008-07-05 18:01:55Z rcaputo $
+# $Id: PoeBuildInfo.pm 2524 2009-04-21 04:01:03Z rcaputo $
 # rocco // vim: ts=2 sw=2 expandtab
 
 # Build information for POE.  Moved into a library so it can be
@@ -20,12 +20,13 @@ use vars qw(@EXPORT_OK);
   DIST_AUTHOR
   RECOMMENDED_TIME_HIRES
   CONFIG_REQUIREMENTS
+  REPOSITORY
 );
 
 
 sub CONFIG_REQUIREMENTS () {
   (
-    "POE::Test::Loops"  => 1.002,
+    "POE::Test::Loops"  => 1.004,
   )
 }
 
@@ -46,7 +47,9 @@ sub CORE_REQUIREMENTS () {
         "Win32::Console" => 0.031,
         "Win32API::File" => 0.05,
       )
-      : ()
+      : (
+        "IO::Tty"        => 1.08, # avoids crashes on fbsd
+      )
     ),
     CONFIG_REQUIREMENTS,
   )
@@ -91,4 +94,8 @@ sub TEST_FILES () {
   "@test_files";
 }
 
+sub REPOSITORY () {
+  ( 'https://poe.svn.sourceforge.net/svnroot/poe/trunk' )
+}
+
 1;
